{% load i18n %} {% load rich_text %} {% if schedule.comment %}

{{ schedule.comment|rich_text }}

{% elif schedule.changes.action == "create" %}

{{ phrases.schedule.first_schedule }}

{% elif not schedule.changes.count %}

–

{% endif %} {% if schedule.changes.count %} {% if schedule.changes.new_talks|length > 0 %} {% if schedule.changes.new_talks|length > 1 %}

{% translate "We have new sessions!" %}

{% for talk in schedule.changes.new_talks %}
- {{ talk.submission.display_title_with_speakers }}
{% endfor %}

{% else %}

{% translate "We have a new session: " %} {% for talk in schedule.changes.new_talks %} {{ talk.submission.display_title_with_speakers }}. {% endfor %} {% endif %}

{% endif %} {% if schedule.changes.canceled_talks|length > 0 %} {% if schedule.changes.canceled_talks|length > 1 %}

{% translate "Sadly, we had to cancel sessions:" %}

{% for talk in schedule.changes.canceled_talks %}
- {{ talk.submission.display_title_with_speakers }}
{% endfor %}

{% else %}

{% translate "We sadly had to cancel a session: " %} {% for talk in schedule.changes.canceled_talks %}{{ talk.submission.display_title_with_speakers }}{% endfor %}

{% endif %} {% endif %} {% if schedule.changes.moved_talks|length > 0 %} {% if schedule.changes.moved_talks|length > 1 %}

{% translate "We had to move some sessions, so if you were planning on seeing them, check their new dates or locations:" %}

{% for talk in schedule.changes.moved_talks %}
- {{ talk.submission.display_title_with_speakers }} {% if talk.old_room == talk.new_room %} ({{ talk.old_start }} → {{ talk.new_start }}) {% elif talk.old_start == talk.new_start %} ({{ talk.old_room.name }} → {{ talk.new_room.name }}) {% else %} ({{ talk.old_start }}, {{ talk.old_room.name }} → {{ talk.new_start }}, {{ talk.new_room.name }}) {% endif %}
{% endfor %}

{% else %}

{% translate "We have moved a session around: " %} {% for talk in schedule.changes.moved_talks %} {{ talk.submission.display_title_with_speakers }} {% if talk.old_room == talk.new_room %} ({{ talk.old_start }} → {{ talk.new_start }}) {% elif talk.old_start == talk.new_start %} ({{ talk.old_room.name }} → {{ talk.new_room.name }}) {% else %} ({{ talk.old_start }}, {{ talk.old_room.name }} → {{ talk.new_start }}, {{ talk.new_room.name }}). {% endif %} {% endfor %}

{% endif %} {% endif %} {% endif %}